@@ -28,9 +28,9 @@
 
 This AWS Solutions Construct implements an Amazon API Gateway REST API connected to Amazon DynamoDB table.
 
-Here is a minimal deployable pattern definition in
+Here is a minimal deployable pattern definition in:
 
-Typescript:
+Typescript
 
 ```python
 import { Construct } from 'constructs';
@@ -117,7 +117,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -129,6 +129,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -156,12 +158,12 @@ class ApiGatewayToDynamoDB(
         allow_delete_operation: typing.Optional[builtins.bool] = None,
         allow_read_operation: typing.Optional[builtins.bool] = None,
         allow_update_operation: typing.Optional[builtins.bool] = None,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
         create_request_template: typing.Optional[builtins.str] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         read_request_template: typing.Optional[builtins.str] = None,
         update_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -185,6 +187,10 @@ class ApiGatewayToDynamoDB(
         :since: 0.8.0
         :summary: Constructs a new instance of the ApiGatewayToDynamoDB class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToDynamoDB.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToDynamoDBProps(
             allow_create_operation=allow_create_operation,
             allow_delete_operation=allow_delete_operation,
@@ -202,27 +208,27 @@ class ApiGatewayToDynamoDB(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayLogGroup")
     def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayRole")
     def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "apiGatewayRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dynamoTable")
     def dynamo_table(self) -> aws_cdk.aws_dynamodb.Table:
         return typing.cast(aws_cdk.aws_dynamodb.Table, jsii.get(self, "dynamoTable"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
     def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
         return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
@@ -254,12 +260,12 @@ class ApiGatewayToDynamoDBProps:
         allow_delete_operation: typing.Optional[builtins.bool] = None,
         allow_read_operation: typing.Optional[builtins.bool] = None,
         allow_update_operation: typing.Optional[builtins.bool] = None,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
         create_request_template: typing.Optional[builtins.str] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         read_request_template: typing.Optional[builtins.str] = None,
         update_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -280,11 +286,25 @@ class ApiGatewayToDynamoDBProps:
         :summary: The properties for the ApiGatewayToDynamoDB class.
         '''
         if isinstance(api_gateway_props, dict):
-            api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
+            api_gateway_props = RestApiProps(**api_gateway_props)
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+            dynamo_table_props = TableProps(**dynamo_table_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToDynamoDBProps.__init__)
+            check_type(argname="argument allow_create_operation", value=allow_create_operation, expected_type=type_hints["allow_create_operation"])
+            check_type(argname="argument allow_delete_operation", value=allow_delete_operation, expected_type=type_hints["allow_delete_operation"])
+            check_type(argname="argument allow_read_operation", value=allow_read_operation, expected_type=type_hints["allow_read_operation"])
+            check_type(argname="argument allow_update_operation", value=allow_update_operation, expected_type=type_hints["allow_update_operation"])
+            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
+            check_type(argname="argument create_request_template", value=create_request_template, expected_type=type_hints["create_request_template"])
+            check_type(argname="argument delete_request_template", value=delete_request_template, expected_type=type_hints["delete_request_template"])
+            check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
+            check_type(argname="argument existing_table_obj", value=existing_table_obj, expected_type=type_hints["existing_table_obj"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument read_request_template", value=read_request_template, expected_type=type_hints["read_request_template"])
+            check_type(argname="argument update_request_template", value=update_request_template, expected_type=type_hints["update_request_template"])
         self._values: typing.Dict[str, typing.Any] = {}
         if allow_create_operation is not None:
             self._values["allow_create_operation"] = allow_create_operation
